/****************************************************************************
** Meta object code from reading C++ file 'qwaylandinputdevice_p.h'
**
** Created by: The Qt Meta Object Compiler version 67 (Qt 5.15.4)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include <memory>
#include "../../../../git/src/client/qwaylandinputdevice_p.h"
#include <QtCore/qbytearray.h>
#include <QtCore/qmetatype.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'qwaylandinputdevice_p.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 67
#error "This file was generated using the moc from 5.15.4. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

QT_BEGIN_MOC_NAMESPACE
QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
struct qt_meta_stringdata_QtWaylandClient__QWaylandInputDevice_t {
    QByteArrayData data[1];
    char stringdata0[37];
};
#define QT_MOC_LITERAL(idx, ofs, len) \
    Q_STATIC_BYTE_ARRAY_DATA_HEADER_INITIALIZER_WITH_OFFSET(len, \
    qptrdiff(offsetof(qt_meta_stringdata_QtWaylandClient__QWaylandInputDevice_t, stringdata0) + ofs \
        - idx * sizeof(QByteArrayData)) \
    )
static const qt_meta_stringdata_QtWaylandClient__QWaylandInputDevice_t qt_meta_stringdata_QtWaylandClient__QWaylandInputDevice = {
    {
QT_MOC_LITERAL(0, 0, 36) // "QtWaylandClient::QWaylandInpu..."

    },
    "QtWaylandClient::QWaylandInputDevice"
};
#undef QT_MOC_LITERAL

static const uint qt_meta_data_QtWaylandClient__QWaylandInputDevice[] = {

 // content:
       8,       // revision
       0,       // classname
       0,    0, // classinfo
       0,    0, // methods
       0,    0, // properties
       0,    0, // enums/sets
       0,    0, // constructors
       0,       // flags
       0,       // signalCount

       0        // eod
};

void QtWaylandClient::QWaylandInputDevice::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    (void)_o;
    (void)_id;
    (void)_c;
    (void)_a;
}

QT_INIT_METAOBJECT const QMetaObject QtWaylandClient::QWaylandInputDevice::staticMetaObject = { {
    QMetaObject::SuperData::link<QObject::staticMetaObject>(),
    qt_meta_stringdata_QtWaylandClient__QWaylandInputDevice.data,
    qt_meta_data_QtWaylandClient__QWaylandInputDevice,
    qt_static_metacall,
    nullptr,
    nullptr
} };


const QMetaObject *QtWaylandClient::QWaylandInputDevice::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *QtWaylandClient::QWaylandInputDevice::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_meta_stringdata_QtWaylandClient__QWaylandInputDevice.stringdata0))
        return static_cast<void*>(this);
    if (!strcmp(_clname, "QtWayland::wl_seat"))
        return static_cast< QtWayland::wl_seat*>(this);
    return QObject::qt_metacast(_clname);
}

int QtWaylandClient::QWaylandInputDevice::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QObject::qt_metacall(_c, _id, _a);
    return _id;
}
struct qt_meta_stringdata_QtWaylandClient__QWaylandInputDevice__Keyboard_t {
    QByteArrayData data[4];
    char stringdata0[85];
};
#define QT_MOC_LITERAL(idx, ofs, len) \
    Q_STATIC_BYTE_ARRAY_DATA_HEADER_INITIALIZER_WITH_OFFSET(len, \
    qptrdiff(offsetof(qt_meta_stringdata_QtWaylandClient__QWaylandInputDevice__Keyboard_t, stringdata0) + ofs \
        - idx * sizeof(QByteArrayData)) \
    )
static const qt_meta_stringdata_QtWaylandClient__QWaylandInputDevice__Keyboard_t qt_meta_stringdata_QtWaylandClient__QWaylandInputDevice__Keyboard = {
    {
QT_MOC_LITERAL(0, 0, 46), // "QtWaylandClient::QWaylandInpu..."
QT_MOC_LITERAL(1, 47, 20), // "handleFocusDestroyed"
QT_MOC_LITERAL(2, 68, 0), // ""
QT_MOC_LITERAL(3, 69, 15) // "handleFocusLost"

    },
    "QtWaylandClient::QWaylandInputDevice::Keyboard\0"
    "handleFocusDestroyed\0\0handleFocusLost"
};
#undef QT_MOC_LITERAL

static const uint qt_meta_data_QtWaylandClient__QWaylandInputDevice__Keyboard[] = {

 // content:
       8,       // revision
       0,       // classname
       0,    0, // classinfo
       2,   14, // methods
       0,    0, // properties
       0,    0, // enums/sets
       0,    0, // constructors
       0,       // flags
       0,       // signalCount

 // slots: name, argc, parameters, tag, flags
       1,    0,   24,    2, 0x08 /* Private */,
       3,    0,   25,    2, 0x08 /* Private */,

 // slots: parameters
    QMetaType::Void,
    QMetaType::Void,

       0        // eod
};

void QtWaylandClient::QWaylandInputDevice::Keyboard::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    if (_c == QMetaObject::InvokeMetaMethod) {
        auto *_t = static_cast<Keyboard *>(_o);
        (void)_t;
        switch (_id) {
        case 0: _t->handleFocusDestroyed(); break;
        case 1: _t->handleFocusLost(); break;
        default: ;
        }
    }
    (void)_a;
}

QT_INIT_METAOBJECT const QMetaObject QtWaylandClient::QWaylandInputDevice::Keyboard::staticMetaObject = { {
    QMetaObject::SuperData::link<QObject::staticMetaObject>(),
    qt_meta_stringdata_QtWaylandClient__QWaylandInputDevice__Keyboard.data,
    qt_meta_data_QtWaylandClient__QWaylandInputDevice__Keyboard,
    qt_static_metacall,
    nullptr,
    nullptr
} };


const QMetaObject *QtWaylandClient::QWaylandInputDevice::Keyboard::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *QtWaylandClient::QWaylandInputDevice::Keyboard::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_meta_stringdata_QtWaylandClient__QWaylandInputDevice__Keyboard.stringdata0))
        return static_cast<void*>(this);
    if (!strcmp(_clname, "QtWayland::wl_keyboard"))
        return static_cast< QtWayland::wl_keyboard*>(this);
    return QObject::qt_metacast(_clname);
}

int QtWaylandClient::QWaylandInputDevice::Keyboard::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QObject::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 2)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 2;
    } else if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 2)
            *reinterpret_cast<int*>(_a[0]) = -1;
        _id -= 2;
    }
    return _id;
}
struct qt_meta_stringdata_QtWaylandClient__QWaylandInputDevice__Pointer_t {
    QByteArrayData data[3];
    char stringdata0[68];
};
#define QT_MOC_LITERAL(idx, ofs, len) \
    Q_STATIC_BYTE_ARRAY_DATA_HEADER_INITIALIZER_WITH_OFFSET(len, \
    qptrdiff(offsetof(qt_meta_stringdata_QtWaylandClient__QWaylandInputDevice__Pointer_t, stringdata0) + ofs \
        - idx * sizeof(QByteArrayData)) \
    )
static const qt_meta_stringdata_QtWaylandClient__QWaylandInputDevice__Pointer_t qt_meta_stringdata_QtWaylandClient__QWaylandInputDevice__Pointer = {
    {
QT_MOC_LITERAL(0, 0, 45), // "QtWaylandClient::QWaylandInpu..."
QT_MOC_LITERAL(1, 46, 20), // "handleFocusDestroyed"
QT_MOC_LITERAL(2, 67, 0) // ""

    },
    "QtWaylandClient::QWaylandInputDevice::Pointer\0"
    "handleFocusDestroyed\0"
};
#undef QT_MOC_LITERAL

static const uint qt_meta_data_QtWaylandClient__QWaylandInputDevice__Pointer[] = {

 // content:
       8,       // revision
       0,       // classname
       0,    0, // classinfo
       1,   14, // methods
       0,    0, // properties
       0,    0, // enums/sets
       0,    0, // constructors
       0,       // flags
       0,       // signalCount

 // slots: name, argc, parameters, tag, flags
       1,    0,   19,    2, 0x08 /* Private */,

 // slots: parameters
    QMetaType::Void,

       0        // eod
};

void QtWaylandClient::QWaylandInputDevice::Pointer::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    if (_c == QMetaObject::InvokeMetaMethod) {
        auto *_t = static_cast<Pointer *>(_o);
        (void)_t;
        switch (_id) {
        case 0: _t->handleFocusDestroyed(); break;
        default: ;
        }
    }
    (void)_a;
}

QT_INIT_METAOBJECT const QMetaObject QtWaylandClient::QWaylandInputDevice::Pointer::staticMetaObject = { {
    QMetaObject::SuperData::link<QObject::staticMetaObject>(),
    qt_meta_stringdata_QtWaylandClient__QWaylandInputDevice__Pointer.data,
    qt_meta_data_QtWaylandClient__QWaylandInputDevice__Pointer,
    qt_static_metacall,
    nullptr,
    nullptr
} };


const QMetaObject *QtWaylandClient::QWaylandInputDevice::Pointer::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *QtWaylandClient::QWaylandInputDevice::Pointer::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_meta_stringdata_QtWaylandClient__QWaylandInputDevice__Pointer.stringdata0))
        return static_cast<void*>(this);
    if (!strcmp(_clname, "QtWayland::wl_pointer"))
        return static_cast< QtWayland::wl_pointer*>(this);
    return QObject::qt_metacast(_clname);
}

int QtWaylandClient::QWaylandInputDevice::Pointer::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QObject::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 1)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 1;
    } else if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 1)
            *reinterpret_cast<int*>(_a[0]) = -1;
        _id -= 1;
    }
    return _id;
}
struct qt_meta_stringdata_QtWaylandClient__QWaylandPointerEvent_t {
    QByteArrayData data[1];
    char stringdata0[38];
};
#define QT_MOC_LITERAL(idx, ofs, len) \
    Q_STATIC_BYTE_ARRAY_DATA_HEADER_INITIALIZER_WITH_OFFSET(len, \
    qptrdiff(offsetof(qt_meta_stringdata_QtWaylandClient__QWaylandPointerEvent_t, stringdata0) + ofs \
        - idx * sizeof(QByteArrayData)) \
    )
static const qt_meta_stringdata_QtWaylandClient__QWaylandPointerEvent_t qt_meta_stringdata_QtWaylandClient__QWaylandPointerEvent = {
    {
QT_MOC_LITERAL(0, 0, 37) // "QtWaylandClient::QWaylandPoin..."

    },
    "QtWaylandClient::QWaylandPointerEvent"
};
#undef QT_MOC_LITERAL

static const uint qt_meta_data_QtWaylandClient__QWaylandPointerEvent[] = {

 // content:
       8,       // revision
       0,       // classname
       0,    0, // classinfo
       0,    0, // methods
       0,    0, // properties
       0,    0, // enums/sets
       0,    0, // constructors
       4,       // flags
       0,       // signalCount

       0        // eod
};

QT_INIT_METAOBJECT const QMetaObject QtWaylandClient::QWaylandPointerEvent::staticMetaObject = { {
    nullptr,
    qt_meta_stringdata_QtWaylandClient__QWaylandPointerEvent.data,
    qt_meta_data_QtWaylandClient__QWaylandPointerEvent,
    nullptr,
    nullptr,
    nullptr
} };

QT_WARNING_POP
QT_END_MOC_NAMESPACE
